# version
%global fftwversion 3.3.9
%global fftwnumversion %( echo %{fftwversion} | tr -d . )

# Turn off hardened stuff
%undefine _hardened_build
%undefine _annotated_build
%undefine _missing_build_ids_terminate_build
%undefine _unique_build_ids

# compiler for which we are doing this
%{!?compiler: %global compiler gcc}
%{!?compilermajor: %global compilermajor 19}
%{!?compilerminor: %global compilerminor 1}
%{!?openmpiversion: %global openmpiversion 4.1.0}
%global openmpinumversion %( printf "%02d%02d%02d" `echo %{openmpiversion} | cut -d. -f1,2,3 --output-delimiter=" "` )
%global compilerrname %{compiler}%{compilerversionnum}

%global with_serial %{?_without_serial: 0}%{?!_without_serial: 1}
%global with_mpich2 0
%global with_openmpi %{?_without_openmpi: 0}%{?!_without_openmpi: 1}
%global with_impi %{?_without_impi: 0}%{?!_without_impi: 1}

# modules defaults
%global modulefile_path_top /usr/local/share/Modules/modulefiles/fftw

# deployment plan:
# top dir /usr/local/fftw/
#                        /gcc/3.3.2
#                        /gcc/openmpi-1.5.4/3.3.2
#                        /intel-12.1/3.3.2
#                        /intel-12.1/openmpi-1.5.4/3.3.2
%global localdir /usr/local/fftw/%{compilerlong}/%{version}
%global localdiropenmpi /usr/local/fftw/%{compilerlong}/openmpi-%{openmpiversion}/%{version}
%global localdirimpi /usr/local/fftw/%{compilerlong}/intel-mpi/%{version}

# now, depending on the compiler we need different things - place them all here for eacy access/changing
#
# GCC Compiler
%if "%{compiler}" == "gcc"
%global compilerruntime %{nil}
%global compilerruntimeopenmpi BuildRequires: openmpi-gcc-devel = %{openmpiversion} \
Requires: openmpi-gcc-runtime >= %{openmpiversion}
%global compilerruntimeimpi BuildRequires: intel-mpi-modules-devel intel-mpi-modules-gcc \
Requires: intel-mpi-modules-gcc 
%global compilerdevel Requires: gcc-gfortran 
%global compilerdevelopenmpi Requires: gcc-gfortran openmpi-gcc-devel >= %{openmpiversion}
%global compilerdevelimpi Requires: gcc-gfortran intel-mpi-modules-devel intel-mpi-modules-gcc
# do nothing special for gcc for build prep
%global compilerbuildprep export F77=gfortran
# no alias
%global modulefile_compiler_alias %{nil}
%global compilershort gcc
%global compilerlong gcc
%global compilerversionnum 446
%global compilerrname gcc
%global compilermodule gcc
# Quad precision support only available with gcc >= 4.6
%global quad 1
# requirements
%global compilerreq %{nil}
# optimizations, remove all extra
%global optflags -O3 -g -pipe -Wall -Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -grecord-gcc-switches -m64 -mtune=generic -fasynchronous-unwind-tables
%endif

%if "%{compiler}" == "intel"
# these two are used to decide which version of intel we will be using to build it all
# and which version we will be providing
%{!?intelminrelease: %global intelminrelease 0}
%global compilerversion %{compilermajor}.%{compilerminor}
%global compilerversionnum %{compilermajor}%{compilerminor}
%global compilerruntime BuildRequires: intel-compiler%{compilermajor}-%{bits}-default-modules-devel >= %{compilerversion}-%{intelminrelease} \
Requires: intel-compiler%{compilermajor}-%{bits}-default-modules >= %{compilerversion}-%{intelminrelease}
%global compilerruntimeopenmpi BuildRequires: openmpi-intel%{compilerversionnum}-devel = %{openmpiversion} intel-compiler%{compilermajor}-%{bits}-default-modules-devel >= %{compilerversion}-%{intelminrelease} \
Requires: openmpi-intel%{compilerversionnum}-runtime >= %{openmpiversion} intel-compiler%{compilermajor}-%{bits}-default-modules >= %{compilerversion}-%{intelminrelease}
%global compilerruntimeimpi BuildRequires: intel-compiler%{compilermajor}-%{bits}-default-modules-devel >= %{compilerversion}-%{intelminrelease}, intel-mpi-modules-devel, intel-mpi-modules-intel \
Requires: intel-mpi-modules-intel intel-compiler%{compilermajor}-%{bits}-default-modules >= %{compilerversion}-%{intelminrelease}
%global compilerdevel Requires: intel-compiler%{compilermajor}-%{bits}-default-modules-devel >= %{compilerversion}-%{intelminrelease}
%global compilerdevelopenmpi Requires: openmpi-intel%{compilerversionnum}-devel >= %{openmpiversion}
%global compilerdevelimpi Requires: intel-compiler%{compilermajor}-%{bits}-default-modules-devel >= %{compilerversion}-%{intelminrelease}, intel-mpi-modules-devel, intel-mpi-modules-intel
# for intel we need to just specify our compilers
%global compilerbuildprep export CC=icc CXX=icpc F77=ifort FC=ifort F90=ifort CPP="icc -E" CXXCPP="icpc -E" LDFLAGS="-Wl,--build-id"; module load intel
%global compilermodule %{compiler}-%{compilermajor}.%{compilerminor}
%global optflags -O3 -ip -no-prec-div -g
# the following is used in above
%global compilershort intel-%{compilermajor}
%global compilerlong intel-%{compilerversion}
# Quad precision support only available with gcc >= 4.6
%global quad 0
%global compilerreq intel
%endif

%if "%{compiler}" == "nvhpc"
%global compilerversion %{compilermajor}.%{compilerminor}
%global compilerversionnum %{compilermajor}%{compilerminor}
%global compilerruntime BuildRequires: pu-nvhpc-%{compilermajor}-%{compilerminor} \
Requires: pu-nvhpc >= %{compilermajor}.%{compilerminor}
%global compilerruntimeopenmpi BuildRequires: openmpi-nvhpc%{compilerversionnum}-devel \
Requires: openmpi-%{compiler}%{compilerversionnum}-runtime >= %{openmpiversion} pu-nvhpc >= %{compilermajor}.%{compilerminor}
%global compilerruntimeimpi %{nil}
%global compilerdevel Requires: pu-nvhpc >= %{compilermajor}.%{compilerminor}
%global compilerdevelopenmpi Requires: openmpi-nvhpc%{compilerversionnum}-devel >= %{openmpiversion}
%global compilerdevelimpi %{nil}
# for nvhpc we need to just specify our compilers
%global compilerbuildprep module load nvhpc
%global compilermodule %{compiler}-%{compilermajor}.%{compilerminor}
%global optflags -O3 -g
# the following is used in above
%global compilershort nvhpc-%{compilermajor}
%global compilerlong nvhpc-%{compilerversion}
# Quad precision support only available with gcc >= 4.6
%global quad 0
%global compilerreq nvhpc
%endif

# where modules really go
%global modulefile_path %{modulefile_path_top}/%{compilerlong}

%ifarch %{ix86}
%global bits 32
%else
%global bits 64
%endif

Name:           fftw%{fftwnumversion}-%{compilerrname}
Version:        %{fftwversion}
Release:        10%{?dist}
Summary:        A Fast Fourier Transform library for %{compilerrname}
Group:          System Environment/Libraries
License:        GPLv2+
URL:            http://www.fftw.org
Source0:        http://www.fftw.org/fftw-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%{compilerruntime}

# OpenMP support not available on RHEL 4
%global openmp 1

# For check phase
BuildRequires:  time
BuildRequires:  perl
# to make openmpi tests work
BuildRequires:  openssh-clients

%if %{quad}
BuildRequires: libquadmath-devel
%endif

Requires(post): info 
Requires(preun): info

%description
FFTW is a C subroutine library for computing the Discrete Fourier
Transform (DFT) in one or more dimensions, of both real and complex
data, and of arbitrary input size.

This version is compiled for compmiler %{compilerrname}

%package devel
Summary:        Headers, libraries and docs for the FFTW library
Group:          Development/Libraries
Requires:       pkgconfig
Requires:       %{name}%{?_isa} = %{version}-%{release}
%{compilerdevel}

%description devel
FFTW is a C subroutine library for computing the Discrete Fourier
Transform (DFT) in one or more dimensions, of both real and complex
data, and of arbitrary input size.

This package contains header files and development libraries needed to
develop programs using the FFTW fast Fourier transform library.

%if %{with_openmpi}
%package openmpi%{openmpinumversion}
Summary: fftw openmpi libraries
Group: Development/Libraries
%{compilerruntimeopenmpi}

%description openmpi%{openmpinumversion}
fftw openmpi libraries

%package openmpi%{openmpinumversion}-devel
Summary: fftw openmpi devel files
Group: Development/Libraries
Requires: %{name}-openmpi%{openmpinumversion} = %{version}-%{release}
%{compilerdevelopenmpi}

%description openmpi%{openmpinumversion}-devel
3ftw openmpi devel files
%endif

%if %{with_impi}
%package impi
Summary: fftw intel mpi libraries
Group: Development/Libraries
%{compilerruntimeimpi}

%description impi
fftw intel mpi libraries

%package impi-devel
Summary: fftw intel mpi devel files
Group: Development/Libraries
Requires: %{name}-impi = %{version}-%{release}
%{compilerdevelimpi}

%description impi-devel
fftw intel mpi devel files
%endif


%prep
%setup -q -n fftw-%{version}


%build
. /etc/profile.d/modules.sh

BASEFLAGS="--enable-shared --disable-dependency-tracking --enable-threads"
%if %{openmp}
BASEFLAGS="$BASEFLAGS --enable-openmp"
%endif

# MPI versions to build
mpi_name[0]=serial
%if %{with_openmpi}
mpi_name[1]=openmpi
%endif
%if %{with_impi}
mpi_name[2]=impi
%endif

mpi_flags[0]=--disable-mpi
mpi_flags[1]=--enable-mpi
mpi_flags[2]=--enable-mpi
mpi_flags[3]=--enable-mpi

mpi_mod[0]=
mpi_mod[1]=openmpi/%{compilermodule}
mpi_mod[2]=intel-mpi/%{compiler}

mpi_prefix[0]=%{localdir}
mpi_prefix[1]=%{localdiropenmpi}
mpi_prefix[2]=%{localdirimpi}

mpi_com[0]=
mpi_com[1]=export MPICC=mpicc
mpi_com[2]=export MPICC=mpicc

# Precisions to build
prec_name[0]=single
prec_name[1]=double
prec_name[2]=long
prec_name[3]=quad

# Corresponding flags
prec_flags[0]="--enable-single --enable-sse2 --enable-avx2"
prec_flags[1]="--enable-double --enable-sse2 --enable-avx2"
prec_flags[2]=--enable-long-double
prec_flags[3]=--enable-quad-precision

# Loop over mpi versions
for((mpi=0;mpi<3;mpi++))
do
# for precision, we have to make sure we do not try quad precision with mpi
if [ "%{quad}${mpi_name[mpi]}" = "1serial" ]; then
maxprec=4
else
maxprec=3
fi
# Loop over precisions
for((iprec=0;iprec<$maxprec;iprec++))
do
 [ -n "${mpi_name[mpi]}" ] || continue
 mkdir ${mpi_name[mpi]}${prec_name[iprec]}${ver_name[iver]}
 cd    ${mpi_name[mpi]}${prec_name[iprec]}${ver_name[iver]}
 ln -s ../configure .
 module purge
 %{compilerbuildprep}
 [ -n ${mpi_mod[mpi]} ] && module load ${mpi_mod[mpi]}
 ${mpi_com[mpi]}
 %{configure} ${BASEFLAGS} ${mpi_flags[mpi]} ${prec_flags[iprec]} \
	--libdir=${mpi_prefix[mpi]}/%{_lib} --bindir=${mpi_prefix[mpi]}/bin \
	--includedir=${mpi_prefix[mpi]}/include --mandir=${mpi_prefix[mpi]}/share/man --infodir=${mpi_prefix[mpi]}/share/info
 sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
 sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
 make %{?_smp_mflags}
 cd ..
done
done

%install
rm -rf %{buildroot}
. /etc/profile.d/modules.sh

# MPI versions to build
mpi_name[0]=serial
%if %{with_openmpi}
mpi_name[1]=openmpi
%endif
%if %{with_impi}
mpi_name[2]=impi
%endif

mpi_mod[0]=
mpi_mod[1]=openmpi/%{compilermodule}
mpi_mod[2]=intel-mpi/%{compiler}

mpi_module[0]=
mpi_module[1]=openmpi-%{openmpiversion}
mpi_module[2]=intel-mpi

mpi_prefix[0]=%{localdir}
mpi_prefix[1]=%{localdiropenmpi}
mpi_prefix[2]=%{localdirimpi}

mpi_com[0]=
mpi_com[1]=export MPICC=mpicc
mpi_com[2]=export MPICC=mpicc

mpi_req[0]="%{compilerreq}"
mpi_req[1]="%{compilerreq} openmpi"
mpi_req[2]="%{compilerreq} intel-mpi"

# Loop over mpi versions
for((mpi=0;mpi<3;mpi++))
do
 [ -n "${mpi_name[mpi]}" ] || continue
%if %{quad}
for ver in single double long quad
%else
for ver in single double long
%endif
do
 # mpi versions do not have quad
 [ "$ver" = "quad" -a "${mpi_name[mpi]}" != "serial" ] && continue
 module purge
 %{compilerbuildprep}
 [ -n ${mpi_mod[mpi]} ] && module load ${mpi_mod[mpi]}
 ${mpi_com[mpi]}
 make -C ${mpi_name[mpi]}$ver install DESTDIR=%{buildroot}
done
# requirements
if [ -n "${mpi_req[mpi]}" ]; then
	prereq="prereq ${mpi_req[mpi]}"
else
	prereq=""
fi
# handle the module
mkdir -p ${RPM_BUILD_ROOT}/%{modulefile_path}/${mpi_module[mpi]}
cat > ${RPM_BUILD_ROOT}/%{modulefile_path}/${mpi_module[mpi]}/%{version} <<ENDMODULE
#%Module

# NOTE: This is an automatically-generated file!  (generated by the
# fftw rpm).  Any changes made here will be lost a) if the RPM is
# uninstalled, or b) if the RPM is upgraded or uninstalled.

proc ModulesHelp { } {
   puts stderr "This module adds fftw %{version} for %{compilerlong} to various paths"
}

module-whatis   "Sets up fftw %{version} for %{compilerlong} in your environment"
conflict fftw
${prereq}

prepend-path PATH "${mpi_prefix[mpi]}/bin"
prepend-path LD_LIBRARY_PATH "${mpi_prefix[mpi]}/%{_lib}"
prepend-path LIBRARY_PATH "${mpi_prefix[mpi]}/%{_lib}"
prepend-path MANPATH "${mpi_prefix[mpi]}/share/man"
setenv FFTW3DIR "${mpi_prefix[mpi]}"
setenv FFTW_PATH "${mpi_prefix[mpi]}"
append-path -d { } LDFLAGS "-L${mpi_prefix[mpi]}/%{_lib}"
append-path -d { } INCLUDE "-I${mpi_prefix[mpi]}/include"
append-path CPATH "${mpi_prefix[mpi]}/include"
append-path -d { } FFLAGS "-I${mpi_prefix[mpi]}/include"
append-path -d { } LOCAL_LDFLAGS "-L${mpi_prefix[mpi]}/%{_lib}"
append-path -d { } LOCAL_INCLUDE "-I${mpi_prefix[mpi]}/include"
append-path -d { } LOCAL_CFLAGS "-I${mpi_prefix[mpi]}/include"
append-path -d { } LOCAL_FFLAGS "-I${mpi_prefix[mpi]}/include"
append-path -d { } LOCAL_CXXFLAGS "-I${mpi_prefix[mpi]}/include"
ENDMODULE
# ah, a lot of software is too stupid to find lib64, help it
pushd  "%{buildroot}/${mpi_prefix[mpi]}"
ln -s lib64 lib
popd
done
for i in `find %{buildroot} -name man1`; do
	gzip -9 $i/*
done
find %{buildroot} -name dir | xargs rm -f
find %{buildroot} -name lib*.la | xargs rm -f

%check
. /etc/profile.d/modules.sh

# MPI versions to build
mpi_name[0]=serial
%if %{with_openmpi}
mpi_name[1]=openmpi
%endif
%if %{with_impi}
mpi_name[2]=impi
%endif

mpi_mod[0]=
mpi_mod[1]=openmpi/%{compilermodule}
mpi_mod[2]=intel-mpi/%{compiler}

mpi_com[0]=
mpi_com[1]=export MPICC=mpicc
mpi_com[2]=export MPICC=mpicc

bdir=`pwd`
# Loop over mpi versions
for((mpi=0;mpi<3;mpi++))
do
 [ -n "${mpi_name[mpi]}" ] || continue
%if %{quad}
for ver in single double long quad
%else
for ver in single double long
%endif
do 
 # No quad option for MPI builds
 [ $ver = "quad" -a -n ${mpi_mod[mpi]} ] && continue
 module purge
 %{compilerbuildprep}
 [ -n ${mpi_mod[mpi]} ] && module load ${mpi_mod[mpi]}
 ${mpi_com[mpi]}
 #LD_LIBRARY_PATH=$bdir/${mpi_name[mpi]}$ver/.libs:$bdir/${mpi_name[mpi]}$ver/threads/.libs:$bdir/${mpi_name[mpi]}$ver/mpi/.libs:$LD_LIBRARY_PATH make -C ${mpi_name[mpi]}$ver check
done
done

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO
%dir %{localdir}
%dir /usr/local/fftw
%dir /usr/local/fftw/%{compilerlong}
%dir %{localdir}/%{_lib}
%{localdir}/lib
%dir %{localdir}/bin
%{localdir}/%{_lib}/libfftw3*.so.*
%dir %{modulefile_path_top}
%dir %{modulefile_path}
%{modulefile_path}/%{version}

%files devel
%defattr(-,root,root,-)
%doc doc/FAQ/fftw-faq.html/
%doc doc/*.pdf doc/html/
%doc %{localdir}/share
%{localdir}/bin/fftw*-wisdom*
%{localdir}/include
%{localdir}/%{_lib}/cmake
%{localdir}/%{_lib}/pkgconfig
%{localdir}/%{_lib}/libfftw3*.so
%{localdir}/%{_lib}/libfftw3*.a

%if %{with_openmpi}
%files openmpi%{openmpinumversion}
%defattr(-,root,root,-)
%doc AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO
%dir %{localdiropenmpi}
%dir /usr/local/fftw
%dir /usr/local/fftw/%{compilerlong}
%dir /usr/local/fftw/%{compilerlong}/openmpi*
%dir %{localdiropenmpi}/bin
%dir %{localdiropenmpi}/%{_lib}
%{localdiropenmpi}/lib
%{localdiropenmpi}/%{_lib}/libfftw3*.so.*
%dir %{modulefile_path_top}
%dir %{modulefile_path}
%dir %{modulefile_path}/openmpi-*
%{modulefile_path}/openmpi-*/%{version}

%files openmpi%{openmpinumversion}-devel
%defattr(-,root,root,-)
%doc %{localdiropenmpi}/share
%{localdiropenmpi}/bin/fftw*-wisdom*
%{localdiropenmpi}/include
%{localdiropenmpi}/%{_lib}/cmake
%{localdiropenmpi}/%{_lib}/pkgconfig
%{localdiropenmpi}/%{_lib}/libfftw3*.so
%{localdiropenmpi}/%{_lib}/libfftw3*.a
%endif

%if %{with_impi}
%files impi
%defattr(-,root,root,-)
%doc AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO
%dir %{localdirimpi}
%dir /usr/local/fftw
%dir /usr/local/fftw/%{compilerlong}
%dir /usr/local/fftw/%{compilerlong}/intel-mpi
%dir %{localdirimpi}/bin
%dir %{localdirimpi}/%{_lib}
%{localdirimpi}/lib
%{localdirimpi}/%{_lib}/libfftw3*.so.*
%dir %{modulefile_path_top}
%dir %{modulefile_path}
%dir %{modulefile_path}/intel-mpi
%{modulefile_path}/intel-mpi/%{version}

%files impi-devel
%defattr(-,root,root,-)
%doc %{localdirimpi}/share
%{localdirimpi}/bin/fftw*-wisdom*
%{localdirimpi}/include
%{localdirimpi}/%{_lib}/cmake
%{localdirimpi}/%{_lib}/pkgconfig
%{localdirimpi}/%{_lib}/libfftw3*.so
%{localdirimpi}/%{_lib}/libfftw3*.a
%endif

%changelog
* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jun 15 2012 Orion Poplawski <orion@cora.nwra.com> - 3.3.2-1
- Update to 3.3.2
- Drop alignment patch

* Fri Apr 27 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.3.1-3
- Fix FTBFS with gcc 4.7.

* Thu Apr 26 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.3.1-2
- Reorganized libraries (BZ #812981).

* Mon Feb 27 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.3.1-1
- Update to 3.3.1.

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Oct 11 2011 Dan Horák <dan[at]danny.cz> - 3.3-4
- libquadmath exists only on x86/x86_64 and ia64

* Mon Oct 10 2011 Rex Dieter <rdieter@fedoraproject.org> 3.3-3
- -devel: Provides: fftw3-devel (#744758)
- -static: Provides: fftw3-static
- drop %%_isa from Obsoletes

* Sat Jul 30 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.3-2
- Conditionalize OpenMP and quadruple precision support based on capabilities
  of system compiler.

* Thu Jul 28 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.3-1
- Update to 3.3.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 9 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.2.2-4
- Get rid of rpath.

* Sat Jan 9 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.2.2-3
- Branch out developers' manual to -doc.

* Sat Jan 2 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.2.2-2
- Add check phase.
- Cosmetic changes to spec file (unified changelog format, removed unnecessary
  space).
- Use rm instead of find -delete, as latter is not present on EPEL-4.
- Generalize obsoletes of fftw3 packages. Add Obsoletes: fftw3-static.

* Fri Jan 1 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 3.2.2-1
- Update to 3.2.2.
- Make file listings more explicit.
- Don't use file dependencies for info.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Feb 14 2009 Conrad Meyer <konrad@tylerc.org> - 3.2.1-1
- Bump to 3.2.1.

* Thu Dec 4 2008 Conrad Meyer <konrad@tylerc.org> - 3.2-1
- Bump to 3.2.

* Fri Jul 18 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 3.1.2-7
- fix license tag

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 3.1.2-6
- Autorebuild for GCC 4.3

* Fri Aug 24 2007 Quentin Spencer <qspencer@users.sf.net> 3.1.2-5
- Rebuild for F8.

* Fri Jul 27 2007 Quentin Spencer <qspencer@users.sf.net> 3.1.2-4
- Split static libs into separate package (bug 249686).

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 3.1.2-3
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Tue Sep 26 2006 Quentin Spencer <qspencer@users.sf.net> 3.1.2-2
- BuildRequires: pkgconfig for -devel (bug 206444).

* Fri Sep  8 2006 Quentin Spencer <qspencer@users.sf.net> 3.1.2-1
- New release.

* Fri Jun  2 2006 Quentin Spencer <qspencer@users.sf.net> 3.1.1-1
- New upstream release.

* Fri Feb 24 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-4
- Re-enable static libs (bug 181897).
- Build long-double version of libraries (bug 182587).

* Mon Feb 13 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-3
- Add Obsoletes and Provides.

* Mon Feb 13 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-2
- Rebuild for Fedora Extras 5.
- Disable static libs.
- Remove obsolete configure options.

* Wed Feb  1 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-1
- Upgrade to the 3.x branch, incorporating changes from the fftw3 spec file.
- Add dist tag.

* Mon May 23 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 2.1.5-8
- BuildReq gcc-gfortran (#156490).

* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 2.1.5-7
- rebuild on all arches
- buildrequire compat-gcc-32-g77

* Fri Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Wed Nov 10 2004 Matthias Saou <http://freshrpms.net/> 2.1.5-5
- Bump release to provide Extras upgrade path.

* Tue Apr 06 2004 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.4
- BuildReq gcc-g77.

* Mon Sep 22 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.3
- Dropped post/preun scripts for info.

* Wed Sep 17 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.2
- Remove aesthetic comments.
- buildroot -> RPM_BUILD_ROOT.
- post/preun for info files.

* Mon Apr 07 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.1
- Updated to 2.1.5.

* Tue Apr 01 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.4-0.fdr.2
- Added Epoch:0.
- Added ldconfig to post and postun.

* Sun Mar 22 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 2.1.4-0.fdr.1
- Updated to 2.1.4.

* Fri Mar 14 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 2.1.3-0.fdr.1
- Fedorafied.

* Mon Oct 21 2002 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Initial RPM release.
